@@ -1,14 +1,17 @@
 #! /bin/bash
 # Tests of xlbiff window behavior.
 
-# programs used:
-# xdotool (packgae xdotool)
-# ps (package procps)
-
 # Usage:
-# test-windowing.sh [--logdir dirname] [--binary path_to_xlbiff]
+# test-windowing.sh [--logdir dirname] [--as-installed]
 
-. $(dirname "$0")/utilities.sh
+. "$(dirname "$0")"/utilities.sh
+
+windowing_dependencies=(
+    xdotool xdotool
+    ps procps
+)
+
+util_check_dependencies "${windowing_dependencies[@]}"
 
 parse_command_line "$@"
 
@@ -32,7 +35,7 @@ is_xlbiff_invisible() {
 }
 
 is_xlbiff_running() {
-    ps ax | grep "$xlbiff_name" | egrep -v -q 'bash|xvfb|grep'
+    ps ax | grep "$xlbiff_name" | grep -E -v -q 'bash|Xvfb|grep'
 }
 
 is_xlbiff_not_running() {
@@ -49,9 +52,7 @@ does_mailer_action_file_exist() {
 
 send_key() {
     local key="$1"
-    if [[ -n "$VERBOSE" ]]; then
-        printf '%s: sending key %s to %s\n' "$0" "$key" "$xlbiff_name"
-    fi
+    util_logv "sending key $key to $xlbiff_name"
     # also send keyup in case client thinks key is still down from
     # a previous half-delivered key
     msg=$(xdotool search --name "$xlbiff_name" \
@@ -60,31 +61,32 @@ send_key() {
     # If the keydown causes the window to unmap, this keyup will fail benignly.
     xdotool search --name "$xlbiff_name" keyup "$key" 2>/dev/null
     if [[ "$keydown_status" != 0 ]]; then
-        if [[ -n "$VERBOSE" ]]; then
-            printf '%s: send %s to %s status %s\n' "$0" \
-                   "$key" "$xlbiff_name" "$keydown_status" "$(echo $msg)"
-        fi
+        util_logv "send $key to $xlbiff_name status $keydown_status $msg"
         return 1
     fi
 }
 
-# Echoes the corner positions
+# sets variable named by $1 to the corner positions
 get_window_corners() {
+    local -n return_var="$1"
     local corners i
-    for ((i=0; i<10; ++i)); do
-        corners=$(xwininfo -name "$xlbiff_name" | grep Corners:)
-        [[ -z "$USE_WM" ]] && break
-        # Upper left corner, with WM, should be +0+37 or +0+1007 (for bottom)
-        [[ ! "$corners" =~ [+]0[+]0 ]] &&
-            [[ ! "$corners" =~ [+]0[+]1005 ]] &&
-            break
-        # WM moves the window after it first maps; wait for it
-        if [[ -n "$VERBOSE" ]]; then
-            printf '%s: waiting with %s\n' "$0" "$corners" >&2
+    for ((i=1; i<=10; ++i)); do
+        corners=$(xwininfo -name "$xlbiff_name" \
+                           2>> "$logdir/xvfb.$current_test_name.log" \
+                      | grep Corners:)
+        if [[ -n "$corners" ]]; then
+            [[ -z "$USE_WM" ]] && break
+            # Upper left corner, with metacity,
+            # should be +0+37 or +0+1007 (for bottom).
+            [[ ! "$corners" =~ [+]0[+]0 ]] &&
+                [[ ! "$corners" =~ [+]0[+]1005 ]] &&
+                break
         fi
+        # WM moves the window after it first maps; wait for it
+        util_logv "waiting $i/10 with $corners"
         sleep 0.1
     done
-    echo "$corners"
+    return_var="$corners"
 }
 
 pass_test_if_window_unmoved() {
@@ -98,7 +100,9 @@ pass_test_if_window_unmoved() {
 is_window_unmoved() {
     local top_bottom_all="$1"
     local corners_1="$2"
-    check_some_corners "$top_bottom_all" "$corners_1" "$(get_window_corners)"
+    local corners_2
+    get_window_corners corners_2
+    check_some_corners "$top_bottom_all" "$corners_1" "$corners_2"
 }
 
 check_some_corners() {
@@ -106,8 +110,8 @@ check_some_corners() {
     local window_corners_1="$2"
     local window_corners_2="$3"
     local corners ul1 ur1 lr1 ll1 ul2 ur2 lr2 ll2
-    read corners ul1 ur1 lr1 ll1 <<<"$window_corners_1"
-    read corners ul2 ur2 lr2 ll2 <<<"$window_corners_2"
+    read -r corners ul1 ur1 lr1 ll1 <<<"$window_corners_1"
+    read -r corners ul2 ur2 lr2 ll2 <<<"$window_corners_2"
     local compare1 compare2
     case $top_bottom_all in
         top) compare1="$ul1" ; compare2="$ul2" ;;
@@ -213,7 +217,8 @@ test_sequence_incmail() {
 run_test_variations incmail test_sequence_incmail
 
 test_sequence_moremail() {
-    local window_corners_1="$(get_window_corners)"
+    local window_corners_1
+    get_window_corners window_corners_1
     send_key "d"
     loop_for 5 is_xlbiff_invisible
     send_new_mail
@@ -233,12 +238,13 @@ test_sequence_moremail() {
 run_test_variations moremail test_sequence_moremail
 
 test_sequence_mailer_noinc() {
-    local window_corners_1="$(get_window_corners)"
+    local window_corners_1 window_corners_2
+    get_window_corners window_corners_1
 
     send_key "m"
     loop_for 5 does_mailer_action_file_exist msg1
     loop_for 5 is_xlbiff_visible msg1
-    local window_corners_2="$(get_window_corners)"
+    get_window_corners window_corners_2
     check_some_corners all "$window_corners_1" "$window_corners_2"
     local test_result_1="$?"
 
@@ -283,11 +289,12 @@ test_sequence_fade() {
     loop_for 10 is_xlbiff_visible
     end_test_with_status pass
 }
-# -fade 0.2 is too fast and makes the test flaky
-run_test_variations fade test_sequence_fade -fade 0.3
+# Any faster than -fade 0.6 makes the test flaky
+run_test_variations fade test_sequence_fade -fade 0.6
 
 test_sequence_refresh() {
-    window_corners_1="$(get_window_corners)"
+    local window_corners_1
+    get_window_corners window_corners_1
     send_key d
     loop_for 10 is_xlbiff_invisible
     loop_for 30 is_xlbiff_visible
